@@ -1,7 +1,8 @@
+import re
+
+from checkov.common.models.consts import DOCKER_IMAGE_REGEX
 from checkov.common.models.enums import CheckCategories, CheckResult
 from checkov.kubernetes.base_spec_check import BaseK8Check
-from checkov.common.models.consts import DOCKER_IMAGE_REGEX
-import re
 
 
 class ImageTagFixed(BaseK8Check):
@@ -20,13 +21,15 @@ class ImageTagFixed(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         if "image" in conf:
 
             # Remove the digest, if present
             image_val = conf["image"]
+            if not isinstance(image_val, str):
+                return CheckResult.FAILED
             if '@' in image_val:
                 image_val = image_val[0:image_val.index('@')]
 
