@@ -13,7 +13,7 @@ class MemoryLimits(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-        return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         if "resources" in conf:
@@ -26,4 +26,5 @@ class MemoryLimits(BaseK8Check):
             return CheckResult.FAILED
         return CheckResult.PASSED
 
-check = MemoryLimits()
\ No newline at end of file
+
+check = MemoryLimits()
