@@ -13,11 +13,12 @@ class Tiller(BaseK8Check):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
     def get_resource_id(self, conf):
-            return conf['parent']
+        return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
         if "image" in conf:
-            if "tiller" in conf["image"]:
+            conf_image = conf["image"]
+            if isinstance(conf_image,str) and  "tiller" in conf_image:
                     return CheckResult.FAILED
         else:
             return CheckResult.FAILED
