@@ -3,12 +3,12 @@ import operator
 import os
 from functools import reduce
 
-from checkov.common.runners.base_runner import BaseRunner
-from checkov.runner_filter import RunnerFilter
 from checkov.common.output.record import Record
 from checkov.common.output.report import Report
+from checkov.common.runners.base_runner import BaseRunner, filter_ignored_directories
 from checkov.kubernetes.parser.parser import parse
 from checkov.kubernetes.registry import registry
+from checkov.runner_filter import RunnerFilter
 
 K8_POSSIBLE_ENDINGS = [".yaml", ".yml", ".json"]
 
@@ -24,7 +24,7 @@ class Runner(BaseRunner):
         files_list = []
         if external_checks_dir:
             for directory in external_checks_dir:
-                registry.load_external_checks(directory)
+                registry.load_external_checks(directory, runner_filter)
 
         if files:
             for file in files:
@@ -34,11 +34,13 @@ class Runner(BaseRunner):
 
         if root_folder:
             for root, d_names, f_names in os.walk(root_folder):
+                filter_ignored_directories(d_names)
+
                 for file in f_names:
                     file_ending = os.path.splitext(file)[1]
                     if file_ending in K8_POSSIBLE_ENDINGS:
                         full_path = os.path.join(root, file)
-                        if 'node_modules' not in full_path and "/." not in full_path and file not in ['package.json','package-lock.json']:
+                        if "/." not in full_path and file not in ['package.json','package-lock.json']:
                             # skip temp directories
                             files_list.append(full_path)
 
@@ -48,11 +50,6 @@ class Runner(BaseRunner):
                 if parse_result:
                     (definitions[relative_file_path], definitions_raw[relative_file_path]) = parse_result
 
-        # Filter out empty files that have not been parsed successfully, and filter out non-K8 template files
-        #definitions = {k: v for k, v in definitions.items() if
-        #               v and (v.__contains__("apiVersion") and v.__contains__("kind"))}
-        #definitions_raw = {k: v for k, v in definitions_raw.items() if k in definitions.keys()}
-
         for k8_file in definitions.keys():
             if definitions[k8_file]:
                 for i in range(len(definitions[k8_file])):
@@ -77,6 +74,19 @@ class Runner(BaseRunner):
                     if entity_conf["kind"] == "List":
                         continue
 
+                    # Skip entity without metadata["name"]
+                    if "metadata" in entity_conf:
+                        if not "name" in entity_conf["metadata"]:
+                            continue
+                    else:
+                        continue
+
+                    # Skip entity with parent (metadata["ownerReferences"]) in runtime
+                    # We will alert in runtime only
+                    if "ownerReferences" in entity_conf["metadata"] and \
+                            entity_conf["metadata"]["ownerReferences"] is not None:
+                        continue
+
                     # Append containers and initContainers to definitions list
                     for type in ["containers", "initContainers"]:
                         containers = []
@@ -94,14 +104,15 @@ class Runner(BaseRunner):
                         else:
                             namespace = "default"
                         containerDef["containers"] = containers.pop()
-                        for cd in containerDef["containers"]:
-                            i = containerDef["containers"].index(cd)
-                            containerDef["containers"][i]["apiVersion"] = entity_conf["apiVersion"]
-                            containerDef["containers"][i]["kind"] = type
-                            containerDef["containers"][i]["parent"] = "{}.{}.{} (container {})".format(
-                                entity_conf["kind"], entity_conf["metadata"]["name"], namespace, str(i))
-                            containerDef["containers"][i]["parent_metadata"] = entity_conf["metadata"]
-                        definitions[k8_file].extend(containerDef["containers"])
+                        if containerDef["containers"] is not None:
+                            for cd in containerDef["containers"]:
+                                i = containerDef["containers"].index(cd)
+                                containerDef["containers"][i]["apiVersion"] = entity_conf["apiVersion"]
+                                containerDef["containers"][i]["kind"] = type
+                                containerDef["containers"][i]["parent"] = "{}.{}.{} (container {})".format(
+                                    entity_conf["kind"], entity_conf["metadata"]["name"], namespace, str(i))
+                                containerDef["containers"][i]["parent_metadata"] = entity_conf["metadata"]
+                            definitions[k8_file].extend(containerDef["containers"])
 
                 # Run for each definition included added container definitions
                 for i in range(len(definitions[k8_file])):
@@ -114,6 +125,21 @@ class Runner(BaseRunner):
                     if entity_conf["kind"] == "List":
                         continue
 
+                    # Skip entity without metadata["name"] or parent_metadata["name"]
+                    if not any(x in entity_conf["kind"] for x in ["containers", "initContainers"]):
+                        if "metadata" in entity_conf:
+                            if not "name" in entity_conf["metadata"]:
+                                continue
+                        else:
+                            continue
+
+                    # Skip entity with parent (metadata["ownerReferences"]) in runtime
+                    # We will alert in runtime only
+                    if "metadata" in entity_conf:
+                        if "ownerReferences" in entity_conf["metadata"] and \
+                                entity_conf["metadata"]["ownerReferences"] is not None:
+                            continue
+
                     # Skip Kustomization Templates (for now)
                     if entity_conf["kind"] == "Kustomization":
                         continue
@@ -145,10 +171,10 @@ class Runner(BaseRunner):
                                         check_class=check.__class__.__module__)
                         report.add_record(record=record)
 
-
         return report
 
 
+
     def _search_deep_keys(self, search_text, k8n_dict, path):
         """Search deep for keys and get their values"""
         keys = []
@@ -187,7 +213,7 @@ def get_skipped_checks(entity_conf):
     else:
         if "metadata" in entity_conf.keys():
             metadata = entity_conf["metadata"]
-    if "annotations" in metadata.keys():
+    if "annotations" in metadata.keys() and metadata["annotations"] is not None:
         for key in metadata["annotations"].keys():
             skipped_item = {}
             if "checkov.io/skip" in key or "bridgecrew.io/skip" in key:
