@@ -1,5 +1,5 @@
-from checkov.terraform.models.enums import CheckResult, CheckCategories
-from checkov.terraform.checks.resource.base_check import BaseResourceCheck
+from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
 
 
 class ElasticsearchNodeToNodeEncryption(BaseResourceCheck):
@@ -18,21 +18,21 @@ class ElasticsearchNodeToNodeEncryption(BaseResourceCheck):
         :return: <CheckResult>
         """
         if "cluster_config" in conf.keys():
-
-            instance_count = conf["cluster_config"][0]["instance_count"][0]
-            if isinstance(instance_count,int):
-                if instance_count > 1:
-                    if "node_to_node_encryption" in conf.keys():
-                        if conf["node_to_node_encryption"][0]["enabled"][0]:
-                            return CheckResult.PASSED
+            cluster_config = conf["cluster_config"][0]
+            if isinstance(cluster_config, dict):
+                if "instance_count" not in cluster_config:
+                    return CheckResult.PASSED
+                instance_count = cluster_config["instance_count"][0]
+                if isinstance(instance_count, int):
+                    if instance_count > 1:
+                        if "node_to_node_encryption" in conf.keys() and conf["node_to_node_encryption"][0]["enabled"][0]:
+                                return CheckResult.PASSED
                         else:
                             return CheckResult.FAILED
                     else:
-                        return CheckResult.FAILED
+                        return CheckResult.PASSED
                 else:
-                    return CheckResult.PASSED
-            else:
-                return CheckResult.UNKNOWN
+                    return CheckResult.UNKNOWN
         return CheckResult.PASSED
 
 
