@@ -1,8 +1,8 @@
-from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
-from checkov.common.models.enums import CheckResult, CheckCategories
+from checkov.terraform.checks.resource.base_resource_negative_value_check import BaseResourceNegativeValueCheck
+from checkov.common.models.enums import CheckCategories
 
 
-class GoogleComputeInstanceOSLogin(BaseResourceCheck):
+class GoogleComputeInstanceOSLogin(BaseResourceNegativeValueCheck):
     def __init__(self):
         name = "Ensure that no instance in the project overrides the project setting for enabling OSLogin" \
                "(OSLogin needs to be enabled in prject metadata for all instances)"
@@ -11,13 +11,11 @@ class GoogleComputeInstanceOSLogin(BaseResourceCheck):
         categories = [CheckCategories.NETWORKING]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-    def scan_resource_conf(self, conf):
-        if 'metadata' in conf.keys():
-            if 'enable-oslogin'in conf['metadata'][0]:
-                if not conf['metadata'][0]['enable-oslogin']:
-                    return CheckResult.FAILED
-        return CheckResult.PASSED
+    def get_inspected_key(self):
+        return 'metadata/[0]/enable-oslogin'
 
+    def get_forbidden_values(self):
+        return [False]
 
 
 check = GoogleComputeInstanceOSLogin()
